==> libgnomedb-0.8.99.tar.bz2: libgnomedb-0.8.99/libgnomedb/gnome-db-list.h <==
/* GNOME DB library
 * Copyright (C) 1999-2001 The Free Software Foundation
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_list_h__)
#  define __gnome_db_list_h__

#include <libgda/gda-data-model.h>
#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_LIST            (gnome_db_list_get_type())
#define GNOME_DB_LIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_LIST, GnomeDbList))
#define GNOME_DB_LIST_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_LIST, GnomeDbListClass))
#define GNOME_DB_IS_LIST(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_LIST))
#define GNOME_DB_IS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_LIST))

typedef struct _GnomeDbList        GnomeDbList;
typedef struct _GnomeDbListClass   GnomeDbListClass;
typedef struct _GnomeDbListPrivate GnomeDbListPrivate;

struct _GnomeDbList {
	GtkVBox parent;
	GnomeDbListPrivate *priv;
};

struct _GnomeDbListClass {
	GtkVBoxClass parent_class;
};

GType      gnome_db_list_get_type (void);
GtkWidget *gnome_db_list_new (void);
GtkWidget *gnome_db_list_new_with_model (GdaDataModel *model, gint col);
void       gnome_db_list_set_model (GnomeDbList *list, GdaDataModel *model, gint col);

G_END_DECLS

#endif

==> libgnomedb-0.8.100.tar.bz2: libgnomedb-0.8.100/libgnomedb/gnome-db-list.h <==
/* GNOME DB library
 * Copyright (C) 1999-2001 The Free Software Foundation
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_list_h__)
#  define __gnome_db_list_h__

#include <libgda/gda-data-model.h>
#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_LIST            (gnome_db_list_get_type())
#define GNOME_DB_LIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_LIST, GnomeDbList))
#define GNOME_DB_LIST_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_LIST, GnomeDbListClass))
#define GNOME_DB_IS_LIST(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_LIST))
#define GNOME_DB_IS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_LIST))

typedef struct _GnomeDbList        GnomeDbList;
typedef struct _GnomeDbListClass   GnomeDbListClass;
typedef struct _GnomeDbListPrivate GnomeDbListPrivate;

struct _GnomeDbList {
	GtkVBox parent;
	GnomeDbListPrivate *priv;
};

struct _GnomeDbListClass {
	GtkVBoxClass parent_class;

	/* signals */
	void (* row_selected)      (GnomeDbList *list, gint row);
	void (* selection_cleared) (GnomeDbList *list);
};

GType         gnome_db_list_get_type (void);
GtkWidget    *gnome_db_list_new (void);
GtkWidget    *gnome_db_list_new_with_model (GdaDataModel *model, gint col);
GdaDataModel *gnome_db_list_get_model (GnomeDbList *list);
void          gnome_db_list_set_model (GnomeDbList *list, GdaDataModel *model, gint col);

G_END_DECLS

#endif
